@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2007-2016 by Dominique Dumont.
+# This software is Copyright (c) 2007-2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -54,19 +54,19 @@ my @element = (
                 type       => 'hash',
                 index_type => 'string',
                 @element,
-                follow => '- hash_with_several_auto_created_id',
+                follow_keys_from => '- hash_with_several_auto_created_id',
             },
             hash_with_allow => {
                 type       => 'hash',
                 index_type => 'string',
                 @element,
-                allow => [qw/foo bar baz/],
+                allow_keys => [qw/foo bar baz/],
             },
             hash_with_allow_from => {
                 type       => 'hash',
                 index_type => 'string',
                 @element,
-                allow_from => '- hash_with_several_auto_created_id',
+                allow_keys_from => '- hash_with_several_auto_created_id',
             },
             ordered_hash => {
                 type       => 'hash',
