@@ -8,9 +8,9 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Itself ;
-$Config::Model::Itself::VERSION = '2.010';
+$Config::Model::Itself::VERSION = '2.011';
 use Mouse ;
-use Config::Model 2.101;
+use Config::Model 2.103;
 use 5.010;
 
 use IO::File ;
@@ -510,7 +510,7 @@ sub write_model_plugin {
         || croak __PACKAGE__," write_model_plugin: undefined plugin_name";
     croak "write_model_plugin: unexpected parameters ",join(' ', keys %args) if %args ;
 
-    my $model = $self->meta_root->dump_as_data ;
+    my $model = $self->meta_root->dump_as_data(mode => 'custom') ;
     # print (Dumper( $model)) ;
 
     my @raw_data = @{$model->{class} || []} ;
@@ -765,7 +765,7 @@ Config::Model::Itself - Model editor for Config::Model
 
 =head1 VERSION
 
-version 2.010
+version 2.011
 
 =head1 SYNOPSIS
 
