@@ -152,7 +152,9 @@ my %assert_payload = (
             'choice' => {
                 type        => 'list',
                 level       => 'hidden',
-                description => 'Specify the possible values',
+                description => 'Specify the possible values of an enum. This can also be used in a '
+                    .'reference element so the possible enum value will be the combination of the '
+                    .'specified choice and the refered to values',
                 warp        => {
                     follow => {
                         t  => '?type',
